@@ -1,11 +1,21 @@
 """
 Custom data objects
 """
+from __future__ import unicode_literals
 from django.core.exceptions import ObjectDoesNotExist
 from django.db.models.loading import get_model
 from django.utils.encoding import StrAndUnicode
 import logging
 
+try:
+    from django.utils import six
+    unicode = six.text_type
+    string_types = six.string_types
+except ImportError:
+    # Python 2, Django 1.3
+    string_types = basestring
+
+
 logger = logging.getLogger('any_urlfield.models')
 
 
@@ -39,7 +49,7 @@ class AnyUrlValue(StrAndUnicode):
         self.type_value = type_value
 
         if url_type_registry.index(type_prefix) is None:
-            raise ValueError("Unsupported AnyUrlValue prefix: {0}".format(type_prefix))
+            raise ValueError("Unsupported AnyUrlValue prefix '{0}'. Supported values are: {1}".format(type_prefix, url_type_registry.keys()))
 
 
     @classmethod
@@ -68,7 +78,7 @@ class AnyUrlValue(StrAndUnicode):
 
         url_type = url_type_registry[prefix]
         if url_type is None:
-            raise ValueError("Unsupported URL prefix in database value '{0}'.".format(url))
+            raise ValueError("Unsupported URL prefix in database value '{0}'. Supported values are: {1}".format(url, url_type_registry.keys()))
 
         if url_type.has_id_value:
             if url_rest == 'None':
@@ -96,7 +106,7 @@ class AnyUrlValue(StrAndUnicode):
         """
         Check whether the references model still exists.
         """
-        if self.url_type.prefix == 'http':
+        if self.url_type.prefix == 'http' and self.type_value:
             return True
         elif self.url_type.has_id_value:
             Model = self.get_model()
@@ -114,7 +124,7 @@ class AnyUrlValue(StrAndUnicode):
         Return the model that this value points to.
         """
         Model = self.url_type.model
-        if isinstance(Model, basestring):
+        if isinstance(Model, string_types):
             app_label, model_name = Model.split(".")  # assome appname.ModelName otherwise.
             Model = get_model(app_label, model_name)
         return Model
@@ -140,13 +150,14 @@ class AnyUrlValue(StrAndUnicode):
         return self.url_type.prefix
 
 
+    # Python 3 support comes from StrAndUnicode
     def __unicode__(self):
         """
         Return the URL that the value points to.
         """
         if self.url_type.has_id_value:
             if not self.type_value:
-                return u""
+                return ""
 
             Model = self.get_model()
             try:
@@ -155,9 +166,9 @@ class AnyUrlValue(StrAndUnicode):
             except ObjectDoesNotExist as e:
                 # Silently fail in templates. Avoid full page crashing.
                 logger.exception("Failed to generate URL for {0}".format(repr(self)))
-                return u"#{0}".format(e.__class__.__name__)
+                return "#{0}".format(e.__class__.__name__)
         else:
-            return self.type_value or u""
+            return self.type_value or ""
 
 
     def __len__(self):
@@ -165,7 +176,7 @@ class AnyUrlValue(StrAndUnicode):
 
 
     def __repr__(self):
-        return "<AnyUrlValue '{0}'>".format(self.to_db_value())
+        return str("<AnyUrlValue '{0}'>".format(self.to_db_value()))
 
 
     def __getattr__(self, item):
@@ -174,3 +185,11 @@ class AnyUrlValue(StrAndUnicode):
 
     def __getitem__(self, item):
         return unicode(self).__getitem__(item)
+
+
+    def __bool__(self):
+        return bool(self.type_value)
+
+
+    # Python 2 support:
+    __nonzero__ = __bool__
