@@ -12,7 +12,7 @@ class UrlType(object):
         if form_field is None:
             # Generate default form field if nothing is provided.
             if has_id_value:
-                form_field = forms.ModelChoiceField(queryset=model._default_manager.all(), widget=widget)
+                form_field = lambda: forms.ModelChoiceField(queryset=model._default_manager.all(), widget=widget)
             else:
                 form_field = forms.CharField(widget=widget)
 
@@ -25,6 +25,31 @@ class UrlType(object):
     def __repr__(self):
         return "<UrlType {0}>".format(self.prefix)
 
+    def get_form_field(self):
+        """
+        Create the form field for the URL type.
+        """
+        if callable(self.form_field):
+            return self.form_field()
+        else:
+            return self.form_field
+
+    def get_widget(self):
+        """
+        Create the widget for the URL type.
+        """
+        form_field = self.get_form_field()
+        widget = form_field.widget
+        if isinstance(widget, type):
+            widget = widget()
+
+        # Widget instantiation needs to happen manually.
+        # Auto skip if choices is not an existing attribute.
+        if getattr(form_field, 'choices', None) and getattr(widget, 'choices', None):
+            widget.choices = form_field.choices
+        return widget
+
+
 
 class UrlTypeRegistry(object):
     """
@@ -105,3 +130,10 @@ class UrlTypeRegistry(object):
             if urltype.prefix == prefix:
                 return i
         return None
+
+
+    def keys(self):
+        """
+        Return the available url type prefixes.
+        """
+        return [urltype.prefix for urltype in self._url_types]
